==> haskell-bytes-0.17.4-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bytes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bytes
version:              0.17.4
visibility:           public
id:                   bytes-0.17.4-GCleSP0mlkoI4FBOYM6Kmf
key:                  bytes-0.17.4-GCleSP0mlkoI4FBOYM6Kmf
license:              BSD-3-Clause
copyright:            Copyright (C) 2013-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             https://github.com/ekmett/bytes
synopsis:             Sharing code for serialization between binary and cereal
description:          Sharing code for serialization between binary and cereal.
category:             Data, Serialization
abi:                  cde05bbd0e7e4f482de51bfc1109cfed
exposed:              True
exposed-modules:
    Data.Bytes.Get Data.Bytes.Put Data.Bytes.Serial Data.Bytes.Signed
    Data.Bytes.VarInt

import-dirs:          /usr/lib/ghc-9.4.8/site-local/bytes-0.17.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bytes-0.17.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bytes-0.17.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bytes
hs-libraries:         HSbytes-0.17.4-GCleSP0mlkoI4FBOYM6Kmf
depends:
    base-4.17.2.1 binary-0.8.9.1
    binary-orphans-1.0.5-A9IdD2cMt9i6xPeHB5Bvx4 bytestring-0.11.5.3
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT containers-0.6.7
    hashable-1.4.4.0-nWtkxUvx9i9tMRJKCZgnw
    scientific-0.3.7.0-BkypiqTAkpN3suN2c81wMx text-2.0.2 time-1.12.2
    transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    unordered-containers-0.2.20-1zjZuvvQz6A9v2Utwl5wnX
    void-0.7.3-H00KtmFLEBuFgBidznP5Pq

haddock-interfaces:   /usr/share/doc/haskell-bytes/html/bytes.haddock
haddock-html:         /usr/share/doc/haskell-bytes/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bytes-0.17.4-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bytes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bytes
version:              0.17.4
visibility:           public
id:                   bytes-0.17.4-zMUOkKylj3A9TXaWqKVho
key:                  bytes-0.17.4-zMUOkKylj3A9TXaWqKVho
license:              BSD-3-Clause
copyright:            Copyright (C) 2013-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             https://github.com/ekmett/bytes
synopsis:             Sharing code for serialization between binary and cereal
description:          Sharing code for serialization between binary and cereal.
category:             Data, Serialization
abi:                  9b2e156e8e50251d2be8752ac89eff12
exposed:              True
exposed-modules:
    Data.Bytes.Get Data.Bytes.Put Data.Bytes.Serial Data.Bytes.Signed
    Data.Bytes.VarInt

import-dirs:          /usr/lib/ghc-9.4.8/site-local/bytes-0.17.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bytes-0.17.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bytes-0.17.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bytes
hs-libraries:         HSbytes-0.17.4-zMUOkKylj3A9TXaWqKVho
depends:
    base-4.17.2.1 binary-0.8.9.1
    binary-orphans-1.0.5-8H1YHpsfuvjBmbHQc0ogOG bytestring-0.11.5.3
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT containers-0.6.7
    hashable-1.4.4.0-nWtkxUvx9i9tMRJKCZgnw
    scientific-0.3.7.0-BkypiqTAkpN3suN2c81wMx text-2.0.2 time-1.12.2
    transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    unordered-containers-0.2.20-1zjZuvvQz6A9v2Utwl5wnX
    void-0.7.3-H00KtmFLEBuFgBidznP5Pq

haddock-interfaces:   /usr/share/doc/haskell-bytes/html/bytes.haddock
haddock-html:         /usr/share/doc/haskell-bytes/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
